@@ -26,6 +26,7 @@
 #include <glib.h>
 #include "fr-process.h"
 #include "fr-command.h"
+#include "file-list.h"
 
 #define FR_TYPE_ARCHIVE            (fr_archive_get_type ())
 #define FR_ARCHIVE(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), FR_TYPE_ARCHIVE, FRArchive))
@@ -67,65 +68,69 @@ struct _FRArchiveClass {
 			  FRProcError *error);
 };
 
-GType        fr_archive_get_type              (void);
+GType            fr_archive_get_type          (void);
 
-FRArchive *  fr_archive_new                   ();
+FRArchive *      fr_archive_new               (void);
 
-void         fr_archive_free                  (FRArchive   *archive);
+void             fr_archive_free              (FRArchive     *archive);
 
-gboolean     fr_archive_new_file              (FRArchive   *archive,
-					       const char  *filename);
+gboolean         fr_archive_new_file          (FRArchive     *archive,
+					       const char    *filename);
 
-gboolean     fr_archive_load                  (FRArchive   *archive,
-					       const char  *filename);
+gboolean         fr_archive_load              (FRArchive     *archive,
+					       const char    *filename);
 
-void         fr_archive_reload                (FRArchive   *archive);
+void             fr_archive_reload            (FRArchive     *archive);
 
-void         fr_archive_rename                (FRArchive   *archive,
-					       const char  *filename);
+void             fr_archive_rename            (FRArchive     *archive,
+					       const char    *filename);
 
-void         fr_archive_add                   (FRArchive   *archive, 
-					       GList       *file_list,
-					       const char  *base_dir,
-					       gboolean     update,
-					       const char  *password,
+void             fr_archive_add               (FRArchive     *archive, 
+					       GList         *file_list,
+					       const char    *base_dir,
+					       gboolean       update,
+					       const char    *password,
 					       FRCompression  compression);
 
-void         fr_archive_add_with_wildcard     (FRArchive   *archive, 
-					       const char  *include_files,
-					       const char  *exclude_files,
-					       const char  *base_dir,
-					       gboolean     update,
-					       gboolean     recursive,
-					       gboolean     follow_links,
-					       gboolean     same_fs,
-					       gboolean     no_backup_files,
-					       gboolean     no_dot_files,
-					       gboolean     ignore_case,
-					       const char  *password,
+VisitDirHandle * fr_archive_add_with_wildcard (FRArchive     *archive, 
+					       const char    *include_files,
+					       const char    *exclude_files,
+					       const char    *base_dir,
+					       gboolean       update,
+					       gboolean       recursive,
+					       gboolean       follow_links,
+					       gboolean       same_fs,
+					       gboolean       no_backup_files,
+					       gboolean       no_dot_files,
+					       gboolean       ignore_case,
+					       const char    *password,
+					       FRCompression  compression,
+					       DoneFunc       done_func,
+					       gpointer       done_data);
+
+VisitDirHandle * fr_archive_add_directory     (FRArchive     *archive, 
+					       const char    *directory,
+					       const char    *base_dir,
+					       gboolean       update,
+					       const char    *password,
+					       FRCompression  compression,
+					       DoneFunc       done_func,
+					       gpointer       done_data);
+
+void             fr_archive_remove            (FRArchive     *archive,
+					       GList         *file_list,
 					       FRCompression  compression);
 
-void         fr_archive_add_directory         (FRArchive   *archive, 
-					       const char  *directory,
-					       const char  *base_dir,
-					       gboolean     update,
-					       const char  *password,
-					       FRCompression  compression);
+void             fr_archive_extract           (FRArchive     *archive,
+					       GList         *file_list,
+					       const char    *dest_dir,
+					       gboolean       skip_older,
+					       gboolean       overwrite,
+					       gboolean       junk_path,
+					       const char    *password);
 
-void         fr_archive_remove                (FRArchive   *archive,
-					       GList       *file_list,
-					       FRCompression  compression);
-
-void         fr_archive_extract               (FRArchive   *archive,
-					       GList       *file_list,
-					       const char  *dest_dir,
-					       gboolean     skip_older,
-					       gboolean     overwrite,
-					       gboolean     junk_path,
-					       const char  *password);
-
-void         fr_archive_test                  (FRArchive   *archive,
-					       const char  *password);
+void             fr_archive_test              (FRArchive     *archive,
+					       const char    *password);
 
 /* utils */
 
